@@ -9,7 +9,8 @@ coxme.control <- function(eps=1e-8,
 			  sparse.calc=NULL,
                           optpar=list(method='BFGS', 
                                       control=list(reltol=1e-5)),
-                          refine.df = 4, refine.detail=FALSE)
+                          refine.df = 4, refine.detail=FALSE,
+                          refine.method="control")
                               {
     if (iter.max <0) stop("Invalid value for iterations")
     if (inner.iter<1) stop("Invalid value for inner iterations")
@@ -25,5 +26,6 @@ coxme.control <- function(eps=1e-8,
         }
     list(eps=eps, toler.chol=toler.chol, iter.max=iter.max,
 	 inner.iter=inner.iter, sparse.calc=sparse.calc,
-         optpar=optpar, refine.df=refine.df, refine.detail=refine.detail)
+         optpar=optpar, refine.df=refine.df, refine.detail=refine.detail,
+         refine.method=refine.method)
     }
