@@ -14,7 +14,7 @@ fit1 <- coxph(Surv(time, status) ~ age + ridge(ecog0, ecog1, ecog2, ecog3,
 fit2 <- coxme(Surv(time, status) ~ age + (ecog0+ecog1+ecog2+ecog3 |1), lung,
               vfixed=.5)
 
-aeq(fit1$coef, c(coef(fit2)$fixed, unlist(fit2$frail)))
+aeq(fit1$coef, c(fixef(fit2), unlist(ranef(fit2))))
 indx <- c(5,1,2,3,4) #in coxme, shrinkage variables are first
 all.equal(fit1$var, as.matrix(fit2$var)[indx, indx])
 
@@ -28,6 +28,7 @@ dummy <- matrix(diag(4), 4, dimnames=list(dname,dname))
 fit5 <- coxme(Surv(time, status) ~ age + (ecog0+ecog1+ecog2+ecog3 |1), lung,
               varlist=dummy)
 all.equal(fit4$log, fit5$log)
-all.equal(fit4$coef, fit5$coef, check.attributes=FALSE) #names will differ
+aeq(fixef(fit4), fixef(fit5))
+all.equal(ranef(fit4), ranef(fit5), check.attributes=FALSE) #names will differ
 
 
